import { inject, Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { catchError, EMPTY, Observable } from 'rxjs';
import { User } from '../model/User';

@Injectable({
  providedIn: 'root',
})
export class UserService {
  private http: HttpClient = inject(HttpClient);

  public getCurrentUser(): Observable<User | null> {
    return this.http.get<User | null>('/backend/user').pipe(catchError(() => EMPTY));
  }

  public createUser(id: string, username: string): Observable<User> {
    return this.http.post<User>('/backend/user', {
      authentikId: id,
      username: username,
    });
  }

  public getOrCreateUser(profile: any): Observable<User> {
    console.log('Full authentik profile:', profile);
    // Authentik format might differ from Keycloak
    // Check different possible locations for the ID and username
    const id = profile.info?.sub || profile['sub'];
    const username = profile.info?.preferred_username || profile['preferred_username'] || profile['email'] || profile['name'];
    
    if (!id || !username) {
      console.error('Could not extract user ID or username from profile', profile);
      throw new Error('Invalid user profile data');
    }
    
    console.log(`Creating user with id: ${id}, username: ${username}`);
    return this.createUser(id, username);
  }
}
